@@ -10,7 +10,7 @@
 #include "daverror.h"
 #include "davitemfetchjob.h"
 
-#include <KIO/Job>
+#include <KIO/StoredTransferJob>
 
 using namespace KDAV;
 namespace KDAV
@@ -160,3 +160,5 @@ void DavItemModifyJobPrivate::conflictingItemFetched(KJob *job)
 
     emitResult();
 }
+
+#include "moc_davitemmodifyjob.cpp"
